@@ -128,7 +128,7 @@ class ExtraRegressTests(TestCase):
         Regression test for #8063: limiting a query shouldn't discard any
         extra() bits.
         """
-        qs = User.objects.all().extra(where=["id=%s"], params=[self.u.id])
+        qs = User.objects.extra(where=["id=%s"], params=[self.u.id])
         self.assertSequenceEqual(qs, [self.u])
         self.assertSequenceEqual(qs[:1], [self.u])
 
