@@ -39,6 +39,13 @@ class GEOSTest(SimpleTestCase, TestDataMixin):
             if geom.hasz:
                 self.assertEqual(g.ewkt, geom.wkt)
 
+    def test_wkt_invalid(self):
+        msg = "String input unrecognized as WKT EWKT, and HEXEWKB."
+        with self.assertRaisesMessage(ValueError, msg):
+            fromstr("POINT(٠٠١ ٠)")
+        with self.assertRaisesMessage(ValueError, msg):
+            fromstr("SRID=٧٥٨٣;POINT(100 0)")
+
     def test_hex(self):
         "Testing HEX output."
         for g in self.geometries.hex_wkt:
@@ -1523,11 +1530,36 @@ class GEOSTest(SimpleTestCase, TestDataMixin):
         self.assertEqual(GEOSGeometry("POINT(1.0e-1 1.0e+1)"), Point(0.1, 10))
 
     def test_normalize(self):
-        g = MultiPoint(Point(0, 0), Point(2, 2), Point(1, 1))
-        self.assertIsNone(g.normalize())
-        self.assertTrue(
-            g.equals_exact(MultiPoint(Point(2, 2), Point(1, 1), Point(0, 0)))
-        )
+        multipoint = MultiPoint(Point(0, 0), Point(2, 2), Point(1, 1))
+        normalized = MultiPoint(Point(2, 2), Point(1, 1), Point(0, 0))
+        # Geometry is normalized in-place and nothing is returned.
+        multipoint_1 = multipoint.clone()
+        self.assertIsNone(multipoint_1.normalize())
+        self.assertEqual(multipoint_1, normalized)
+        # If the `clone` keyword is set, then the geometry is not modified and
+        # a normalized clone of the geometry is returned instead.
+        multipoint_2 = multipoint.normalize(clone=True)
+        self.assertEqual(multipoint_2, normalized)
+        self.assertNotEqual(multipoint, normalized)
+
+    @skipIf(geos_version_tuple() < (3, 8), "GEOS >= 3.8.0 is required")
+    def test_make_valid(self):
+        poly = GEOSGeometry("POLYGON((0 0, 0 23, 23 0, 23 23, 0 0))")
+        self.assertIs(poly.valid, False)
+        valid_poly = poly.make_valid()
+        self.assertIs(valid_poly.valid, True)
+        self.assertNotEqual(valid_poly, poly)
+
+        valid_poly2 = valid_poly.make_valid()
+        self.assertIs(valid_poly2.valid, True)
+        self.assertEqual(valid_poly, valid_poly2)
+
+    @mock.patch("django.contrib.gis.geos.libgeos.geos_version", lambda: b"3.7.3")
+    def test_make_valid_geos_version(self):
+        msg = "GEOSGeometry.make_valid() requires GEOS >= 3.8.0."
+        poly = GEOSGeometry("POLYGON((0 0, 0 23, 23 0, 23 23, 0 0))")
+        with self.assertRaisesMessage(GEOSException, msg):
+            poly.make_valid()
 
     def test_empty_point(self):
         p = Point(srid=4326)
